..
   Do not edit this .rst file directly — it’s generated programmatically.
   See doc/reference.sh.

==================================================
Module: ``accounts``
==================================================

`Leer en español </es/latest/reference/accounts.html>`_

- **list accounts**
- **get account**

**COMMANDS**


**list accounts**

List basic information of the main cPanel account.

*Example*

.. code:: sh

    $ cpanel list accounts

See a sample of the JSON result data at:
https://api.docs.cpanel.net/openapi/cpanel/operation/list_accounts/

**get account**

Show detailed information of the main account.

*Example*

.. code:: sh

    $ cpanel get account

See a sample of the JSON result data at:
https://api.docs.cpanel.net/openapi/cpanel/operation/Variables-get_user_information/


